import javax.ws.rs.*;
import javax.ws.rs.core.*;
  

// ressource racine de l'application web
@Path("/app")
public class HelloRootResource
{
  // ** requete GET sans parametre
  // url: localhost:8182/app/hello
  @GET
  @Path("/hello")
  @Produces("text/plain")
  public String hello()
  {
    return "Hello world !\n";
  }

  // ** requete GET, analyse du header HTTP
  // url: localhost:8182/app/ping
  @GET
  @Path("/ping")
  @Produces("text/plain")
  public String ping(@HeaderParam("Host") String host)
  {
    return "ping from: " + host;
  }

  // ** requete GET, une partie du chemin en tant que parametre
  // url: localhost:8182/app/echo/toto
  @GET
  @Path("/echo/{msg}")
  @Produces("text/plain")
  public String echo(@PathParam("msg") String msg)
  {
      return "Hello: " + msg;
  }

  // **requete GET, parametre dans l'URI
  // url: localhost:8182/app/query?msg=toto
  @GET
  @Path("/query")
  @Produces("text/plain")
  public String query(@QueryParam("msg") String msg)
  {
      return "Hello: " + msg;
  }

  // ** exemple de requete PUT avec recuperation du body en text/plain
  @PUT
  @Path("/put")
  @Consumes(MediaType.TEXT_PLAIN)
  @Produces(MediaType.TEXT_PLAIN)
  public String putTest(String content)
  {
    System.out.println("# received put (text) :" + content);
    return "Hello Text : " + content;
  }
  
  // ** exemple de requete PUT avec parsing du body en text/xml
  // ** Note: meme chemin que la version text/plain. Le Content-Type est utilise pour router les requetes
  @PUT
  @Path("/put")
  @Consumes(MediaType.TEXT_XML)
  @Produces(MediaType.TEXT_PLAIN)
  public String putXml(HelloObject h)
  {
    System.out.println("# received put (xml) : " + h.id);
    return "Hello XML- id = " + h.id;
  }

  // ** exemple de requete POST avec recuperation du body et parametre
  @POST
  @Path("/post")
  @Consumes(MediaType.TEXT_PLAIN)
  @Produces(MediaType.TEXT_PLAIN)
  public String post(String content, @QueryParam("id") String id)
  {
    System.out.println("# received post : " + content);
    return "Hello: id = " + id + " ; content : " + content;
  }

  // ** requete GET avec resultat serialise en XML
  // url: localhost:8182/app/xml?id=42
  @GET
  @Path("/xml")
  @Produces(MediaType.APPLICATION_XML)
  public Response helloxml(@QueryParam("id") int id)
  {
    HelloObject h = new HelloObject(id);
    
    return Response.ok().entity(h).type(MediaType.APPLICATION_XML).build();
  }
  
}

